summaryrefslogtreecommitdiff
path: root/board/eve/board.c
diff options
context:
space:
mode:
authorDuncan Laurie <dlaurie@google.com>2018-01-31 12:55:27 -0800
committerchrome-bot <chrome-bot@chromium.org>2018-02-12 18:59:32 -0800
commit52e5ab0730b79d17a60c403bdf9f0d49f3ec2709 (patch)
tree1c3d9377304eb2bff006c34c60281170684f99e4 /board/eve/board.c
parentdb93a8d74c52bc30945120c0f43c527c8af3148c (diff)
downloadchrome-ec-52e5ab0730b79d17a60c403bdf9f0d49f3ec2709.tar.gz
eve: Use PCH ACOK signal to control Deep Sleep entry
Deep Sleep states (DS3, DS5) are a special mode of the Intel PCH chipset that has very limited wake capabilities and breaks a number of common user expected behahviors. In particular, when in Deep S3 the USB ports are turned off and cannot continue to charge, wake the system, or maintain their internal state as they will lose 5V power. This is particularly painful with gnubby devices as they will need unlocked after every DS3 suspend/resume cycle. The only external signal that the PCH uses to determine whether or not to enter Deep Sx states is the ACPRESENT (aka ACOK) pin. Currently this pin is simply buffered from the charger and will be asserted whenever a charger is connected. This change extends the EC control over the pin to also assert ACPRESENT if either Type-C port is currently supplying VBUS. Now when a USB device is inserted the system will be enter S3 state, but not go into Deep S3 state. This allows the USB device to continue to charge, maintain it's internal state, and wake the system. BUG=b:64406191 BRANCH=eve TEST=verify GPIO_PCH_ACOK pin from the EC in different scenarios and test that system goes into S3 or DS3 state as expected: 1) no charger, no USB device: ACOK not asserted, DS3 enabled 2) charger but no USB device: ACOK asserted, DS3 disabled 3) no charger but USB device: ACOK asserted, DS3 disabled 4) charger and USB device: ACOK asserted, DS3 disabled Change-Id: I1cd132459194382e418970d29b1b195d8132cfad Signed-off-by: Duncan Laurie <dlaurie@google.com> Reviewed-on: https://chromium-review.googlesource.com/896164 Reviewed-by: Furquan Shaikh <furquan@chromium.org>
Diffstat (limited to 'board/eve/board.c')
-rw-r--r--board/eve/board.c26
1 files changed, 15 insertions, 11 deletions
diff --git a/board/eve/board.c b/board/eve/board.c
index 77de5ef0f5..0f0fabce6b 100644
--- a/board/eve/board.c
+++ b/board/eve/board.c
@@ -444,6 +444,19 @@ int board_has_working_reset_flags(void)
return 1;
}
+/*
+ * Update status of the ACPRESENT pin on the PCH. In order to prevent
+ * Deep S3 when USB is inserted this will indicate that AC is present
+ * if either port is supplying VBUS or there an external charger present.
+ */
+void board_update_ac_status(void)
+{
+ gpio_set_level(GPIO_PCH_ACOK, extpower_is_present() ||
+ board_vbus_source_enabled(0) ||
+ board_vbus_source_enabled(1));
+}
+DECLARE_HOOK(HOOK_AC_CHANGE, board_update_ac_status, HOOK_PRIO_DEFAULT);
+
/* Initialize board. */
static void board_init(void)
{
@@ -459,8 +472,8 @@ static void board_init(void)
/* Enable interrupts from BMI160 sensor. */
gpio_enable_interrupt(GPIO_ACCELGYRO3_INT_L);
- /* Provide AC status to the PCH */
- gpio_set_level(GPIO_PCH_ACOK, extpower_is_present());
+ /* Update AC status to the PCH */
+ board_update_ac_status();
#if defined(CONFIG_KEYBOARD_SCANCODE_MUTABLE) && !defined(TEST_BUILD)
if (board_get_version() == 4) {
@@ -473,15 +486,6 @@ static void board_init(void)
}
DECLARE_HOOK(HOOK_INIT, board_init, HOOK_PRIO_DEFAULT);
-/**
- * Buffer the AC present GPIO to the PCH.
- */
-static void board_extpower(void)
-{
- gpio_set_level(GPIO_PCH_ACOK, extpower_is_present());
-}
-DECLARE_HOOK(HOOK_AC_CHANGE, board_extpower, HOOK_PRIO_DEFAULT);
-
int pd_snk_is_vbus_provided(int port)
{
if (port != 0 && port != 1)